Queue

Struct Queue 

pub struct Queue { /* private fields */ }
A persisted, low-latency message queue.

Uses memory-mapped files organized into cycle files based on time.

Thread Safety

  • One Writer per thread
  • Multiple Readers can read concurrently
  • The queue itself is Send + Sync

Example

use khata_rs::Queue;

let queue = Queue::new("/tmp/my-queue").build()?;

let mut writer = queue.writer()?;
writer.write(b"Hello, World!")?;

Implementations

Source

impl Queue

pub fn new(path: impl Into<PathBuf>) -> QueueBuilder

Creates a new builder for a queue at the given path.

pub fn writer(&self) -> Result<Writer<'_>>

Creates a writer for appending messages.

Errors

Returns Error::ReadOnly if opened in read-only mode.

pub fn reader(&self) -> Result<Reader<'_>>

Creates a reader for consuming messages.

pub fn path(&self) -> &Path

Returns the queue directory path.

pub fn roll_cycle(&self) -> &dyn RollCycle

Returns the roll cycle configuration.

pub fn block_size(&self) -> usize

Returns the block size.

pub fn epoch(&self) -> u64

Returns the epoch offset.

pub fn is_read_only(&self) -> bool

Returns whether the queue is read-only.

pub fn checksums_enabled(&self) -> bool

Returns whether CRC-16 checksums are enabled.

pub fn index_spacing(&self) -> u32

Returns the index spacing.

pub fn index_count(&self) -> u32

Returns the index count per array.

pub fn first_cycle(&self) -> Option<i32>

Returns the first (oldest) cycle, if any.

pub fn last_cycle(&self) -> Option<i32>

Returns the last (newest) cycle, if any.

pub fn current_cycle(&self) -> i32

Returns the current cycle based on current time.

pub fn filename_for_cycle(&self, cycle: i32) -> String

Generates the filename for a given cycle.